@@ -1,4 +1,4 @@
-from pytest import fixture
+from pytest import fixture, raises
 
 from .. import Rule
 from ..rule import get_rule
@@ -23,8 +23,17 @@ from . import PytestRequest
     "github.value.ResolveToPRDelta",
 ))
 def rule_name(request: PytestRequest[str]) -> str:
+    """Return the name of an existing rule."""
     return request.param
 
 
 def test_import_rule(rule_name: str) -> None:
+    """Make sure this function can import any existing rule."""
     assert issubclass(get_rule(rule_name), Rule)
+
+
+def test_import_rule_failure() -> None:
+    """Make sure this function can't import arbitrary objects."""
+    for rule_name in ["time.sleep", "random.Random"]:
+        with raises(Exception):
+            get_rule(rule_name)
